==> python-proliantutils_2.11.0.orig.tar.gz: proliantutils-2.11.0/proliantutils/tests/redfish/resources/system/test_pci_device.py <==
# Copyright 2017 Hewlett Packard Enterprise Development LP
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import json

import mock
import testtools

from proliantutils.redfish.resources.system import pci_device


class PCIDeviceTestCase(testtools.TestCase):

    def setUp(self):
        super(PCIDeviceTestCase, self).setUp()
        self.conn = mock.Mock()
        pci_file = 'proliantutils/tests/redfish/json_samples/pci_device.json'
        with open(pci_file, 'r') as f:
            self.json_doc = json.load(f)
        self.conn.get.return_value.json.return_value = self.json_doc

        pci_path = "/redfish/v1/Systems/1/PCIDevices/1"
        self.sys_pci = pci_device.PCIDevice(
            self.conn, pci_path, '1.0.2', None)

    def test__parse_attributes(self):
        self.sys_pci._parse_attributes(self.json_doc)
        self.assertEqual('1.0.2', self.sys_pci.redfish_version)
        self.assertEqual('1', self.sys_pci.identity)
        self.assertEqual(1, self.sys_pci.nic_capacity)


class PCIDeviceCollectionTestCase(testtools.TestCase):

    def setUp(self):
        super(PCIDeviceCollectionTestCase, self).setUp()
        self.conn = mock.Mock()
        with open('proliantutils/tests/redfish/json_samples/'
                  'pci_device_collection.json') as f:
            self.json_doc = json.load(f)
        self.conn.get.return_value.json.return_value = self.json_doc
        self.sys_pci_col = pci_device.PCIDeviceCollection(
            self.conn, '/redfish/v1/Systems/1/PCIDevices',
            redfish_version='1.0.2')

    def test__parse_attributes(self):
        self.sys_pci_col._parse_attributes(self.json_doc)
        self.assertEqual('1.0.2', self.sys_pci_col.redfish_version)
        self.assertEqual('PciDevices', self.sys_pci_col.name)
        pci_path = ('/redfish/v1/Systems/1/PCIDevices/1',
                    '/redfish/v1/Systems/1/PCIDevices/6')
        self.assertEqual(pci_path, self.sys_pci_col.members_identities)

    @mock.patch.object(pci_device, 'PCIDevice', autospec=True)
    def test_get_member(self, mock_pci):
        self.sys_pci_col.get_member(
            '/redfish/v1/Systems/1/PCIDevices/1')
        mock_pci.assert_called_once_with(
            self.sys_pci_col._conn,
            ('/redfish/v1/Systems/1/PCIDevices/1'),
            self.sys_pci_col.redfish_version, None)

    @mock.patch.object(pci_device, 'PCIDevice', autospec=True)
    def test_get_members(self, mock_pci):
        members = self.sys_pci_col.get_members()
        path_list = ["/redfish/v1/Systems/1/PCIDevices/1",
                     "/redfish/v1/Systems/1/PCIDevices/6"]
        calls = [
            mock.call(self.sys_pci_col._conn, path_list[0],
                      self.sys_pci_col.redfish_version, None),
            mock.call(self.sys_pci_col._conn, path_list[1],
                      self.sys_pci_col.redfish_version, None)
        ]
        mock_pci.assert_has_calls(calls)
        self.assertIsInstance(members, list)
        self.assertEqual(2, len(members))

    def test_gpu_devices(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device1.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        expected = ["/redfish/v1/Systems/1/PCIDevices/6/"]
        actual = self.sys_pci_col.gpu_devices
        self.assertEqual(1, len(actual))
        self.assertEqual(expected, actual)

    def test_max_nic_capacity(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device1.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        actual_capacity = self.sys_pci_col.max_nic_capacity
        expected = '1Gb'
        self.assertEqual(expected, actual_capacity)

    def test_vendor_id(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device1.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        expected_vendor_id = {'6': 4139}
        self.assertEqual(expected_vendor_id,
                         self.sys_pci_col.vendor_id)

==> python-proliantutils_2.12.2.orig.tar.gz: proliantutils-2.12.2/proliantutils/tests/redfish/resources/system/test_pci_device.py <==
# Copyright 2017 Hewlett Packard Enterprise Development LP
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import json

import mock
import testtools

from proliantutils.redfish.resources.system import pci_device


class PCIDeviceTestCase(testtools.TestCase):

    def setUp(self):
        super(PCIDeviceTestCase, self).setUp()
        self.conn = mock.Mock()
        pci_file = 'proliantutils/tests/redfish/json_samples/pci_device.json'
        with open(pci_file, 'r') as f:
            self.json_doc = json.load(f)
        self.conn.get.return_value.json.return_value = self.json_doc

        pci_path = "/redfish/v1/Systems/1/PCIDevices/1"
        self.sys_pci = pci_device.PCIDevice(
            self.conn, pci_path, redfish_version='1.0.2',
            registries=None, root=None)

    def test__parse_attributes(self):
        self.sys_pci._parse_attributes(self.json_doc)
        self.assertEqual('1.0.2', self.sys_pci.redfish_version)
        self.assertEqual('1', self.sys_pci.identity)
        self.assertEqual(1, self.sys_pci.nic_capacity)


class PCIDeviceCollectionTestCase(testtools.TestCase):

    def setUp(self):
        super(PCIDeviceCollectionTestCase, self).setUp()
        self.conn = mock.Mock()
        with open('proliantutils/tests/redfish/json_samples/'
                  'pci_device_collection.json') as f:
            self.json_doc = json.load(f)
        self.conn.get.return_value.json.return_value = self.json_doc
        self.sys_pci_col = pci_device.PCIDeviceCollection(
            self.conn, '/redfish/v1/Systems/1/PCIDevices',
            redfish_version='1.0.2', registries=None, root=None)

    def test__parse_attributes(self):
        self.sys_pci_col._parse_attributes(self.json_doc)
        self.assertEqual('1.0.2', self.sys_pci_col.redfish_version)
        self.assertEqual('PciDevices', self.sys_pci_col.name)
        pci_path = ('/redfish/v1/Systems/1/PCIDevices/1',
                    '/redfish/v1/Systems/1/PCIDevices/6')
        self.assertEqual(pci_path, self.sys_pci_col.members_identities)

    @mock.patch.object(pci_device, 'PCIDevice', autospec=True)
    def test_get_member(self, mock_pci):
        self.sys_pci_col.get_member(
            '/redfish/v1/Systems/1/PCIDevices/1')
        mock_pci.assert_called_once_with(
            self.sys_pci_col._conn,
            ('/redfish/v1/Systems/1/PCIDevices/1'),
            redfish_version=self.sys_pci_col.redfish_version,
            registries=None, root=self.sys_pci_col.root)

    @mock.patch.object(pci_device, 'PCIDevice', autospec=True)
    def test_get_members(self, mock_pci):
        members = self.sys_pci_col.get_members()
        path_list = ["/redfish/v1/Systems/1/PCIDevices/1",
                     "/redfish/v1/Systems/1/PCIDevices/6"]
        calls = [
            mock.call(self.sys_pci_col._conn, path_list[0],
                      redfish_version=self.sys_pci_col.redfish_version,
                      registries=None, root=self.sys_pci_col.root),
            mock.call(self.sys_pci_col._conn, path_list[1],
                      redfish_version=self.sys_pci_col.redfish_version,
                      registries=None, root=self.sys_pci_col.root)
        ]
        mock_pci.assert_has_calls(calls)
        self.assertIsInstance(members, list)
        self.assertEqual(2, len(members))

    def test_gpu_devices(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device1.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        expected = ["/redfish/v1/Systems/1/PCIDevices/6/"]
        actual = self.sys_pci_col.gpu_devices
        self.assertEqual(1, len(actual))
        self.assertEqual(expected, actual)

    def test_max_nic_capacity(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device1.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        actual_capacity = self.sys_pci_col.max_nic_capacity
        expected = '1Gb'
        self.assertEqual(expected, actual_capacity)

    def test_vendor_id(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        path = ('proliantutils/tests/redfish/json_samples/'
                'pci_device1.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        expected_vendor_id = {'6': 4139}
        self.assertEqual(expected_vendor_id,
                         self.sys_pci_col.vendor_id)
